﻿using Newtonsoft.Json;
using SqlSugar;
using System;
using System.Collections.Generic;
using System.ComponentModel.DataAnnotations.Schema;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using XF.Domain.Entities;
using XF.Domain.Repository;

namespace FileStorage
{
    /// <summary>
    /// 文件数据
    /// </summary>
    public class FileMetadata : CreationEntity,IDisposable
    {
        /// <summary>
        /// 所属客户端
        /// </summary>
        public string Client { get; set; }

        /// <summary>
        /// 文件名
        /// </summary>
        public string FileName { get; set; }

        /// <summary>
        /// 扩展名
        /// </summary>
        public string FileExt { get; set; }

        /// <summary>
        /// 路径
        /// </summary>
        public string Path { get; set; }
        
        /// <summary>
        /// 文件大小
        /// </summary>
        public long Length { get; set; }

        /// <summary>
        /// 保存方式
        /// </summary>
        public string SaveMode { get; set; }

        /// <summary>
        /// 说明
        /// </summary>
        public string ExtraInfo { get; set; }

        /// <summary>
        /// 文件流
        /// </summary>
        [SugarColumn( IsIgnore = true)]
        public Stream DataStream { get; set; }

        /// <summary>
        /// 上传时间
        /// </summary>
        public DateTime UploadTime { get; set; }

        /// <summary>
        /// 释放文件流
        /// </summary>
        public void Dispose()
        {
            if(DataStream!=null)
                DataStream.Dispose();
        }

    }
}
